#
# spec file for package NetworkManager-openvpn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           NetworkManager-openvpn
Version:        1.12.0
Release:        1.3
Summary:        NetworkManager VPN support for OpenVPN
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://www.gnome.org/projects/NetworkManager
Source0:        https://download.gnome.org/sources/NetworkManager-openvpn/1.12/%{name}-%{version}.tar.xz
Source1:        system-user-nm-openvpn.conf
# PATCH-FIX-OPENSUSE fix-for-missing-whirlpool-hmac-authentication.patch boo#1132946
Patch0:         fix-for-missing-whirlpool-hmac-authentication.patch

BuildRequires:  libxml2-tools
BuildRequires:  pkgconfig
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk4) >= 4.0
BuildRequires:  pkgconfig(libnm) >= 1.46.2
BuildRequires:  pkgconfig(libnma) >= 1.8.0
BuildRequires:  pkgconfig(libnma-gtk4) >= 1.8.33
BuildRequires:  pkgconfig(libsecret-1) >= 0.18
Requires:       NetworkManager >= 1.46.2
Requires:       openvpn
Supplements:    (NetworkManager and openvpn)
%sysusers_requires
ExcludeArch:    s390

%description
NetworkManager-openvpn provides VPN support to NetworkManager for
OpenVPN.

%package -n NetworkManager-applet-openvpn
Summary:        NetworkManager VPN support for OpenVPN
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-frontend
Provides:       %{name}-gnome = %{version}
Obsoletes:      %{name}-gnome
Supplements:    (%{name} and NetworkManager-applet)
Supplements:    (%{name} and gnome-control-center)

%description -n NetworkManager-applet-openvpn
NetworkManager-openvpn provides VPN support to NetworkManager for
OpenVPN.

%lang_package

%prep
%autosetup -p1

%build
%configure\
	--disable-static \
	--with-gtk4=yes \
	--enable-lto=yes \
	%{nil}
%make_build
%sysusers_generate_pre %{SOURCE1} NetworkManager-openvpn system-user-nm-openvpn.conf

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_sysusersdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_sysusersdir}/

%pre -f NetworkManager-openvpn.pre

%files
%license COPYING
%doc README
%{_libdir}/NetworkManager/libnm-vpn-plugin-openvpn.so
%{_libexecdir}/nm-openvpn-service
%{_libexecdir}/nm-openvpn-service-openvpn-helper
%{_vpnservicedir}/nm-openvpn-service.name
%{_datadir}/dbus-1/system.d/nm-openvpn-service.conf
%{_sysusersdir}/system-user-nm-openvpn.conf

%files -n NetworkManager-applet-openvpn
%{_datadir}/metainfo/network-manager-openvpn.metainfo.xml
%{_libexecdir}/nm-openvpn-auth-dialog
%{_libdir}/NetworkManager/libnm-vpn-plugin-openvpn-editor.so
%{_libdir}/NetworkManager/libnm-gtk4-vpn-plugin-openvpn-editor.so

%files lang -f %{name}.lang

%changelog
* Mon Jun 24 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.12.0:
  + Adapt to the new way of handling the 2FA secret by the daemon,
    needed by it to fix a bug with certain clients.
  + Updated translations.
* Thu Mar 28 2024 Jonathan Kang <songchuan.kang@suse.com>
- Add missing supplements(bsc#1220391):
  + NMA subpackage: Main package and gnome-control-center
* Thu Nov  2 2023 Callum Farmer <gmbr3@opensuse.org>
- Rename gnome subpackage to NetworkManager-applet-openvpn
  to more accurately reflect its usage
- Add missing supplements:
  - NM and openvpn
  - NMA subpackage: Main package and NMA
* Fri Sep  8 2023 Jonathan Kang <songchuan.kang@suse.com>
- Add nm-openvpn-fix-importing-pkcs12-ca.patch: import: fix
  importing profiles with PKCS#12 CA
  (glgo#GNOME/NetworkManager-openvpn!50, bsc#1214415).
- Drop nm-openvpn-fix-importing-pkcs12-ca.patch: fixed upstream.
* Fri Nov 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.10.2:
  + IP condfiguration is no longer required in TAP mode.
  + Fix initialization of secret flags.
  + Add support for DOMAIN-SEARCH option.
  + Set data-ciphers option with chosen cipher.
  + Update translations.
* Mon Aug 29 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.10.0:
  + Add support for "allow-compression" parameter.
  + Fix a regression in preserving the "tls-auth" settings.
  + Add support for "tls-min" and "tls-cipher" parameters.
  + Include the new gnome-control-center name in the AppData file.
  + Drop libnm-glib support, nobody is likely using it anymore.
  + Fix importing profiles with a PKCS#12 CA.
  + Make sure the plugin object links with glib.
  + Dropped dependency on intltool.
  + Updated translations.
- Drop intltool BuildRequires following upstream changes.
- Rebase patch with quilt.
* Sat Mar 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.18:
  + Gtk4 version of the editor plugin is now available (for use
    with Control Center of GNOME 42 or later).
  + Updated translations.
- Drop nm-openvpn-bsc#1186091.patch: Fixed upstream.
- Rebase patch with quilt.
- Add pkgconfig(gtk4) and pkgconfig(libnma-gtk4) BuildRequires and
  pass --with-gtk4=yes to configure, build the gtk4 version.
- Stop passing --without-libnm-glib to configure, no longer
  needed, nor recognized.
- Pass --enable-lto=yes to configure, build using LTO support.
- Add optional libxml2-tools BuildRequires, build runs
  xml-stripblanks preprocessing if available.
* Wed Sep 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.16:
  + Fix detection of OpenVPN 2.5.0
  + Allow the connection to persist across network failures when
    the VPN profile has 'vpn.persistent=yes'
  + Fix parsing of incomplete IPv6 configurations pushed by server
  + Improve logging message about deprecated tls-remote option
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Wed Jun 16 2021 Jonathan Kang <songchuan.kang@suse.com>
- Add nm-openvpn-bsc#1186091.patch: service: Don't add cert and key
  when they are not set
  (glgo#GNOME/NetworkManager-openvpn!38, bsc#1186091).
* Sun Jun 13 2021 Callum Farmer <gmbr3@opensuse.org>
- Add now working CONFIG parameter to sysusers generator
* Thu Jun  3 2021 Callum Farmer <gmbr3@opensuse.org>
- Change to using systemd-sysusers
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.8.14:
  + Add support for the following OpenVPN options: push-peer-info,
    remote-random-hostname, tls-crypt-v2.
  + Add --explicit-exit-notify by default when using UDP.
  + Fix compatibility issues with OpenVPN 2.5.0.
  + Update translations.
* Fri May  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Set the path for the VPN service name file correctly to
  %%_vpnservicedir (provided by macros.NetworkManager).
* Fri Mar  6 2020 bjorn.lie@gmail.com
- Update to version 1.8.12:
  + The auth helper in external UI mode can now be run without a
    display server. Future nmcli version will utilize this for
    handling the secrets without a graphical desktop.
  + libnm-glib compatibility (NetworkManager < 1.0) is disabled by
    default. It can be enabled by passing --with-libnm-glib to
    configure script. Nobody should need it by now. Users that
    still use this are encouraged to let us know before the
    libnm-glib support is removed for good.
  + Add support for the following OpenVPN options: tls-version-min,
    tls-version-max, compress.
  + Support inline CRL blobs during import.
  + Allow option mssfix to be set to zero.
  + Updated translations.
* Thu Jan 16 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Stop recommending NetworkManager-openvpn-lang: the -lang package
  provides relevant supplements.
* Wed May  1 2019 stefan.pledl@mesutronic.de
- Enable missing whirlpool HMAC authentication (boo#1132946).
  + fix-for-missing-whirlpool-hmac-authentication.patch
* Fri Feb  8 2019 bjorn.lie@gmail.com
- Update to version 1.8.10:
  + Fix changing the proxy port in the editor.
  + Drop the file extension check when importing a file.
  + Support loading the editor shared object from the same
    directory of plugin for development purposes.
  + Updated translations.
* Wed Oct 17 2018 bjorn.lie@gmail.com
- Update to version 1.8.8:
  + Fix a memory corruption bug in the advanced dialog.
  + Updated translations.
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 1.8.6:
  + Don't validate auth parameter and pass it directly to openvpn.
  + Fix endless loop checking for encrypted certificate.
  + Sanitize newlines in export ovpn file.
  + Improve project description in doap file.
  + Various minor bugfixes and improvements.
  + Updated translations.
- Use autosetup and make_build macros.
* Mon May 28 2018 bjorn.lie@gmail.com
- Update to version 1.8.4:
  + Add support for the crl-verify option (bgo#782309)
  + Fix termination of openvpn process upon disconnect
    (rh#1576600).
  + Updated translations.
* Sat Apr 14 2018 bjorn.lie@gmail.com
- Following changes in NetworkManager: pass without-libnm-glib to
  configure, no longer build deprecated libnm-glib support.
- Following the above changes: Drop no longer needed
  pkgconfig(NetworkManager), pkgconfig(libnm-glib),
  pkgconfig(libnm-glib-vpn), pkgconfig(libnm-gtk) and
  pkgconfig(libnm-util) BuildRequires.
- Package missing COPYING file.
- Package nm-openvpn-service.conf as config, silence rpmlint.
- Drop unnneeded NetworkManager-gnome Requires from gnome
  sub-package, it is not longer of use for us.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 1.8.2:
  + Handle more then 255 routes (bgo#788137).
  + Fix GUI for editing connection with static key (bgo#788226).
  + Fix parsing gateway in helper script (bgo#788514).
  + Fix parsing 2FA challenge for "PASSWORD:Verification Failed"
    (bgo#751842).
  + Fix parsing remote hosts from configuration (bgo#792252).
  + Fix assertion failure while quitting service (bgo#792252).
  + Add support for connect-timeout (bgo#792252).
  + Automatically lower connect-timeout if there are multiple
    remotes to try at least 3 remotes (bgo#792252).
  + Add support for extra-certs (bgo#793746).
  + Various code cleanups.
  + Updated translations.
- Drop NetworkManager-openvpn-config.patch: fixed upstream.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Sep 29 2017 dimstar@opensuse.org
- Add NetworkManager-openvpn-config.patch: fix unusable config
  imports (certificate config was wrongly written out, causing the
  VPN profile not be be functional).
* Fri Sep 22 2017 zaitor@opensuse.org
- Update to version 1.8.0:
  + Use gresources for ui files.
  + Use NMACertChooser for PKCS#11 support.
  + Support --ifconfig option not only for static key connections
    (bgo#774727).
  + Fix import for key-direction to make it independent of the
    order (bgo#778154).
  + Extend support for address family specifier for remote protocol
    (bgo#731620).
  + Updated translations.
- Drop
  add-support-for-IP-address-family-specifier-for-remote.patch:
  Fixed upstream.
- Drop obsolete post(un) handling of icon_theme_cache_post(un), no
  longer needed, there is no icon files anymore.
- Run spec-cleaner, modernize spec.
* Tue Aug 29 2017 sckang@suse.com
- modify add-support-for-IP-address-family-specifier-for-remote.patch:
  modify this patch according to the commit pushed to upstream
  master branch.
* Wed Aug 23 2017 sckang@suse.com
- add add-support-for-IP-address-family-specifier-for-remote.patch:
  add support for IP address family specifier for remote protocol
  (fate#322475, bgo#731620).
* Mon May 29 2017 zaitor@opensuse.org
- Update to version 1.2.10:
  + Add support for "tls-crypt" and "mtu-disc" options.
  + Add support for dynamic challenge-response protocol.
  + Allow choosing Adaptive or None LZO compression methods in the
    connection properties dialog.
  + Avoid passing the obsolete "tls-remote" option to OpenVPN
    versions that no longer support it and discourage its use in
    the properties dialog.
  + Updated the build system to use non-recursive make.
  + Many bug fixes.
  + Updated translations.
* Tue Jan 24 2017 dimstar@opensuse.org
- Update to version 1.2.8:
  + Treat cipher and hmac options case insensitive in the
    properties GUI.
  + Support numeric argument to mssfix option.
  + Fixes to translatable strings and use Unicode.
  + Updated translations.
* Mon Jan 23 2017 dimstar@opensuse.org
- Enable build for s390x: the entire dependency chain is in place.
* Tue Oct  4 2016 zaitor@opensuse.org
- Update to version 1.2.6:
  + Restore previous behavior for handling empty "comp-lzo"
    (bgo#769177).
  + Support verify-x509-name (bgo#770922).
  + Support max-routes (bgo#720097).
  + Fix invalid free when parsing remote option.
  + Various cleanups.
  + Updated translations.
- Drop NetworkManager-openvpn-dl-linking.patch: Fixed upstream.
  Following this: Drop libtool BuildRequires and stop passing
  autoreconf, we no longer carry any patches.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon Aug 29 2016 dimstar@opensuse.org
- Update to version 1.2.4:
  + Prefer building against stable libsecret API.
  + Split libnm-vpn-plugin-openvpn.so into a GTK-free core plugin
    usable by nmcli and a UI plugin for nm-applet and gnome
    components.
  + Support NM_VPN_LOG_LEVEL environment variable to control debug
    logging from NetworkManager.
  + Fix handling comp-lzo option.
  + Add support for tls-cipher option.
  + Add support for IPv6 DNS servers.
  + Fix handling quotes and comments when parsing ovpn files.
  + Hide internal ABI from properties libraries.
  + Preserve IP routing configuration on restart.
  + Various cleanups.
  + Updated translations.
- Replace pkgconfig(libsecret-unstable) BuildRequires with
  pkgconfig(libsecret-1), following upstream.
- Drop --disable-more-warnings configure parameter: no longer
  needed.
- Add NetworkManager-openvpn-dl-linking.patch: Fix build by linking
  libdl (bgo#769783).
* Thu Apr  7 2016 zaitor@opensuse.org
- Update to version 1.2.2:
  + Fixed validation of proxy port.
  + Use a proper name for the AppStream metadata.
  + Updated translations.
* Thu Apr  7 2016 dimstar@opensuse.org
- Update to version 1.2.0:
  + build: don't include the full path to a plugin by default.
  + service: drop off the bus when done.
  + import/export: don't limit reneg-sec to 65536 on import.
  + Updated translations.
* Thu Apr  7 2016 dimstar@opensuse.org
- Update to version 1.1.93 (1.2-rc1):
  + service,properties: add support for --ns-cert-type option.
- Changes from version 1.1.92:
  + Code refactoring.
  + Bugs fixed: bgo#763039, bgo#763122, bgo#763320, bgo#763742,
    bgo#764132.
  + Updated translations.
* Thu Apr  7 2016 dimstar@opensuse.org
- Update to version 1.1.91:
  + Add support for importing inline keys, secrets and PKCS12
    certificates.
  + Bugs fixed: bgo#760746, bgo#760904, bgo#760968, bgo#760987,
    bgo#761198, bgo#761285, bgo#761299, bgo#761907, bgo#762678.
  + Updated translations.
* Thu Apr  7 2016 dimstar@opensuse.org
- Update to version 1.1.90:
  + Ported to libnm, libnma and GDBus.
  + Support multiple concurrent OpenVPN connections.
  + Various import/export fixes.
  + Add support for --ping option to backend.
  + Updated translations.
- Add pkgconfig(libnm) and pkgconfig(libnma) BuildRequires: new
  dependencies.
- Drop nm-openvpn-desktop.patch: No longer needed.
- Remove NetworkManager-openvpn-openvpn-settings.png source file:
  as there is no desktop file left, there is also no need for an
  icon.
* Thu Apr  7 2016 sckang@suse.com
- Update to GNOME 3.20 Fate#318572
* Sun Nov 22 2015 zaitor@opensuse.org
- Update to version 1.0.8:
  + Fix operations in IPv6-only configurations.
  + Add support for importing configurations with inline
    certificates.
  + Do not require password if user chose not to store it.
  + Cosmetic UI fixes.
  + Updated translations.
* Mon Sep  7 2015 dimstar@opensuse.org
- Create user/group nm-openvpn: NM-openvpn now runs as unprivileged
  user (as does NM-openconnect already) (boo#944665).
* Tue Sep  1 2015 simon@simotek.net
- Update to version 1.0.6:
  + Enhanced the GUI to support agent-owned and always-ask
    passwords.
  + Support running unprivileged.
  + Updated translations.
* Wed May  6 2015 dimstar@opensuse.org
- Update to version 1.0.2:
  + Default to disabling periodic renegotioation. This avoids
    renegotiating unnecessarily if the server doesn't specify a
    renegotiation timeout, improving usability for OTP users.
  + Build fixes.
  + Updated translations.
* Tue Jan 27 2015 dimstar@opensuse.org
- Update to version 1.0.0:
  + Use Unix socket for management instead of local TCP socket.
  + Make password requests more robust.
  + Allow specifying port and protocol for multiple remotes (VPN
    gateways).
  + updated translations.
* Fri Jan 23 2015 tampakrap@opensuse.org
- Make NetworkManager-openvpn-frontend a recommended dependency, as
  it can work fine on systems without any DE installed.
* Fri Jul 11 2014 dimstar@opensuse.org
- Update to version 0.9.10.0:
  + Allow specifying custom interface name and key size.
  + Better handle --up-restart.
  + Use libsecret for password storage instead of gnome-keyring.
  + Add support for interactive password queries from openvpn.
  + Add support for IPv6 tunnels.
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-unstable), following upstreams switch to
  libsecret.
- Rebase nm-openvpn-desktop.patch.
- Add pkgconfig(libnm-gtk) BuildRequires: new dependency.
* Fri Sep 13 2013 dimstar@opensuse.org
- Update to version 0.9.8.4:
  + Fixed paths in VPN service file.
  + Fixed localization in non-UTF-8 locales.
  + Updated translations.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 0.9.8.2:
  + Use full paths for auth dialog and properties plugin.
  + Handle multiple domain names.
  + Updated translations.
* Fri Feb 22 2013 zaitor@opensuse.org
- Update to version 0.9.8.0:
  + Builds against the GNOME 3.8 versions of GLib and Gtk+.
  + nm-openvpn-service now returns translated error messages.
  + Add support for the 'remote-cert-tls' method for verifying the
    server certificate.
  + Fixed import/export to handle multiple remote servers.
  + No longer asks for a password when using a passwordless auth
    mode.
  + Updated translations.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 0.9.6.0:
  + Updated translations.
* Fri Jun 29 2012 dimstar@opensuse.org
- Update to version 0.9.5.95:
  + Add option to randomize connect order to openvpn servers/peers
  + Updated translations.
* Sat Mar 24 2012 vuntz@opensuse.org
- Update to version 0.9.4.0:
  + Fix auth failure in some case.
  + Updated translations.
* Fri Mar  2 2012 dimstar@opensuse.org
- Update to version 0.9.3.995:
  + Fix issues with password dialog width on recent GTK+ versions
  + Allow cipher and HMAC options to be set for Static Key mode
  + Support for "external UI mode" for DE-native dialogs (ie, GNOME
    Shell and others)
  + Updated translations.
- Add explicit pkgconfig(libnm-glib-vpn) BuildRequires: it's a long
  standing requirement which currently comes implicit with
  libnm-glib, as it's part of the same package at this moment.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Nov 12 2011 dimstar@opensuse.org
- Update to version 0.9.2.0:
  + Updated translations.
- Pass --disable-more-warnings to configure to allow building with
  gtk+ 3.3.
- Really enable parallel build: fix typo smp_flags => smp_mflags.
* Tue Nov  1 2011 dimstar@opensuse.org
- Update to version 0.9.1.95:
  + Updated translations.
* Tue Aug 23 2011 dimstar@opensuse.org
- Update to version 0.9.0:
  + Use a simplified password request dialog.
  + Simplify keyring access and don't save secrets.
  + Preserve secret flags and consolidate secrets handling.
* Thu Jul  7 2011 vuntz@opensuse.org
- Update to version 0.8.9997:
  + Ensure saved secrets are passed back to NM.
  + Add RSA-MD4 HMAC digest algorithm.
  + Stop using deprecated GTK+ API.
  + Updated translations.
* Wed May  4 2011 dimstar@opensuse.org
- Update to version 0.8.999:
  + Export HTTP proxy authfile.
  + Default to agent-owned secrets for new connections.
  + Fix HTTP Proxy authentication autodetection.
  + Updated translations.
* Thu Apr 21 2011 vuntz@opensuse.org
- Drop unneeded libglade2-devel, libgnomeui-devel,
  libgudev-1_0-devel, perl-XML-Parser, update-desktop-files
  BuildRequires.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: NetworkManager-devel, NetworkManager-gnome.
  + New ones: NetworkManager, dbus-glib-1, libnm-glib, libnm-util,
    gnome-keyring-1.
- Stop owning /etc/NetworkManager/VPN as it's owned by
  NetworkManager now.
* Tue Apr  5 2011 dimstar@opensuse.org
- Update to version 0.8.998 (0.9.0-rc1):
  + Bugs fixed: bgo#645911.
  + Updated translations.
* Wed Mar 16 2011 dimstar@opensuse.org
- Update to version 0.8.995 (0.9.0-beta1):
  + simpler, easier, more flexible, and cooler applets.
  + Fast User Switching.
  + WiMAX support.
  + System connections by default.
  + More flexible system administration.
  + Scales down to smaller devices.
- Drop nm-openvpn-show-unencrypted-private-keys-files.patch: fixed
  upstream.
- Add pkgconfig(gtk+-3.0) BuildRequires.
* Mon Feb 21 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Feb 15 2011 binli@opensuse.org
- Add nm-openvpn-show-unencrypted-private-keys-files.patch, show
  unencrypted private files in file chooser dialog(bnc#662577).
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Remove ldconfig from %%post/%%postun: there is no library there.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Sat Nov  6 2010 dimstar@opensuse.org
- Update to version 0.8.2:
  + Fixes to ensure correct IP configuration of tunnels
  + Support for HTTP and SOCKS proxies
  + Better debugging options
  + Updated translations.
- Split out -lang package.
* Mon May 10 2010 dimstar@opensuse.org
- Update to 0.8.1:
  + Support for tun-mtu fragment and mss-fix options
  + PKCS#12 and PKCS#8 private keys
  + RIPMED-160 HMAC auth
  + Improved handling of unencrypted private keys
  + Updated translations
* Tue Feb 23 2010 dimstar@opensuse.org
- Update to version 0.8:
  + build: disabled .desktop for now
  + bgo#606998 - core: handle remote VPN peer correctly in share
    key mode too
  + Updated translations.
* Sat Jan 30 2010 captain.magnus@opensuse.org
- Update to version 0.7.999:
  + import/export: handle 'port' and 'rport' correctly
    (bgo#604329) (lp#443174)
  + export: fix tls-auth export
  + core: add tls-remote support (bgo#455142)
  + Translation updates
- Remove nm-openvpn-sscanf.patch. Was not in use
* Thu Jan 21 2010 tambet@novell.com
- Upgrade to the latest upstream 0.8 branch:
  + Add tls-remote support.
  + Handle 'subnet' topology better.
  + Import/export improvements.
  + Bug fixes.
  + Translation updates.
* Mon Nov 16 2009 aj@suse.de
- Regenerate patches to apply cleanly.
* Mon Oct 19 2009 martin.matuska@vx.sk
- Remove script-security patch for use with OpenVPN 2.1
- Add sscanf patch from upstream (bnc #547573)
* Tue Jul 21 2009 coolo@novell.com
- fix use of %%_libexecdir
* Fri Jun  5 2009 tambet@novell.com
- Upgrade to 0.7.1.
* Wed Feb 11 2009 vuntz@novell.com
- Remove non-upstream translations: they'll get out-of-date.
* Sun Feb  8 2009 schwab@suse.de
- Don't crash on invalid connection-type.
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Translation update.
* Fri Nov  7 2008 bili@suse.de
- Search for certificates from the directory where the
  configuration file is from (bnc #437963).
* Fri Oct 24 2008 tambet@suse.de
- The "Certificates (TLS)" tab should also be present for
  NM_OPENVPN_CONTYPE_PASSWORD.
- Accept ".cer" extension for certificates.
- Handle route_vpn_gateway (bgo #549196).
* Fri Oct 10 2008 tambet@suse.de
- Fix the User and CA certificate entries in Password TLS mode,
  they were swapped with their labels (rh #464765).
* Fri Sep 26 2008 tambet@suse.de
- Fix crashes when creating and deleting connections.
- Add password widgets (bnc #395564).
* Fri Sep 19 2008 tambet@suse.de
- Fix openvpn activations. Upstream uses newer openvpn and
  generates command line not suitable for our openvpn.
* Fri Sep 12 2008 tambet@suse.de
- Bring up to date with SVN.
- Require more specifc version of NetworkManager.
* Sat Aug  2 2008 tambet@suse.de
- Bring up to date with SVN again.
* Wed Jul 16 2008 bili@suse.de
- Upgrade to 0.7.0.r3820 from upstream for build failed.
* Fri May 16 2008 bili@suse.de
- Upgrade to 0.7.0.r3647(bnc#389155).
* Thu Jan 17 2008 tambet@suse.de
- Upgrade to 0.7.0.
* Tue Dec  4 2007 bili@suse.de
- Add the scroll window in properties dialog (Novell #183004).
* Wed Aug  8 2007 tambet@suse.de
- Package the .so file again (Novell #298430).
* Tue Jun  5 2007 sbrabec@suse.cz
- Removed bogus definition of datadir.
- Fixed invalid desktop file patch.
- Fixed mixing of MIME and application icons.
- Call ldconfig.
* Tue May 15 2007 pgajdos@suse.cz
- removed gnome-icon-theme from BuildRequires [#247450]
* Mon Mar 19 2007 hschaa@suse.de
- Replace all occurrences of "/opt/gnome" with "%%{prefix}"
* Mon Feb 12 2007 hschaa@suse.de
- Branch off the NetworkManager-openvpn-gnome package to avoid
  gnome dependencies when using knetworkmanager instead of
  nm-applet (Novell #198529).
* Tue Sep  5 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Aug  2 2006 danw@suse.de
- intltoolize before autoreconf'ing to avoid version skew between
  configure macros and po/Makefile.in.in
* Fri Jun 16 2006 rml@suse.de
- Update translations (Novell bug #169096)
* Thu Jun 15 2006 gekker@suse.de
- Update package to install all available translations (#179731)
* Mon Jun  5 2006 rml@suse.de
- Update translations (Novell bug #169096)
- Break translations out of nm-openvpn-0.6-branch.patch, place in
  separate nm-openvpn-po-update.patch
- Properties dialog: Glade file update (GNOME bug #336913)
* Thu May 18 2006 rml@suse.de
- Update translations (Novell bug #158997)
* Mon Apr 17 2006 rml@suse.de
- Property dialog: Mark the entries as non-editable, since they are
  in fact not user-editable (Novell bug #164989)
* Mon Apr 10 2006 rml@suse.de
- Report error if configuration exportation fails (Novell #164980)
* Wed Mar 29 2006 rml@suse.de
- Send per-route MSS information to NetworkManager (bug #157988)
* Mon Mar 20 2006 rml@suse.de
- Require NetworkManager-gnome (Novell bug #158691)
* Thu Feb  2 2006 rml@suse.de
- Update to 0.3.2cvs20060202
- Update NM API
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 rml@suse.de
- Update to 20060119
* Thu Jan 12 2006 rml@suse.de
- Update to 20060112
* Wed Jan  4 2006 rml@suse.de
- Update to 20060104
* Mon Dec 12 2005 rml@suse.de
- Update to 0.3.2cvs20051212
- Add Tango icons
* Wed Dec  7 2005 rml@suse.de
- Update to 0.3.1cvs20051207
* Thu Dec  1 2005 rml@suse.de
- Update to 0.2.0cvs20051201
* Mon Nov 14 2005 rml@suse.de
- Initial checkin, version 0.1.0cvs20051114
